gkm package
===========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   gkm.deviance
   gkm.kernel
   gkm.links

Submodules
----------

gkm.amsgrad module
------------------

.. automodule:: gkm.amsgrad
   :members:
   :undoc-members:
   :show-inheritance:

gkm.gkm module
--------------

.. automodule:: gkm.gkm
   :members:
   :undoc-members:
   :show-inheritance:

gkm.glm module
--------------

.. automodule:: gkm.glm
   :members:
   :undoc-members:
   :show-inheritance:

gkm.helpers module
------------------

.. automodule:: gkm.helpers
   :members:
   :undoc-members:
   :show-inheritance:

gkm.loss module
---------------

.. automodule:: gkm.loss
   :members:
   :undoc-members:
   :show-inheritance:

gkm.newton module
-----------------

.. automodule:: gkm.newton
   :members:
   :undoc-members:
   :show-inheritance:

gkm.optimized\_gkm module
-------------------------

.. automodule:: gkm.optimized_gkm
   :members:
   :undoc-members:
   :show-inheritance:

gkm.regularization module
-------------------------

.. automodule:: gkm.regularization
   :members:
   :undoc-members:
   :show-inheritance:

gkm.rendered module
-------------------

.. automodule:: gkm.rendered
   :members:
   :undoc-members:
   :show-inheritance:

gkm.validation module
---------------------

.. automodule:: gkm.validation
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: gkm
   :members:
   :undoc-members:
   :show-inheritance:
